pub struct SetUserPropertyParams {
pub property_key: String,
pub body: Option<Value>,
pub account_id: Option<String>,
pub user_key: Option<String>,
pub username: Option<String>,
}Expand description
struct for passing parameters to the method set_user_property
Fields
property_key: StringThe key of the user’s property. The maximum length is 255 characters.
body: Option<Value>account_id: Option<String>The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, 5b10ac8d82e05b22cc7d4ef5.
user_key: Option<String>This parameter is no longer available and will be removed from the documentation soon. See the deprecation notice for details.
username: Option<String>This parameter is no longer available and will be removed from the documentation soon. See the deprecation notice for details.