pub struct FindUserKeysByQueryParams {
pub query: String,
pub start_at: Option<i64>,
pub max_results: Option<i32>,
}Expand description
struct for passing parameters to the method find_user_keys_by_query
Fields
query: StringThe search query.
start_at: Option<i64>The index of the first item to return in a page of results (page offset).
max_results: Option<i32>The maximum number of items to return per page.