pub struct MultiIssueEntityProperties {
pub issues: Option<Vec<IssueEntityPropertiesForMultiUpdate>>,
}Expand description
MultiIssueEntityProperties : A list of issues and their respective properties to set or update. See Entity properties for more information.
Fields
issues: Option<Vec<IssueEntityPropertiesForMultiUpdate>>A list of issue IDs and their respective properties.
Implementations
Sourceimpl MultiIssueEntityProperties
impl MultiIssueEntityProperties
Sourcepub fn new() -> MultiIssueEntityProperties
pub fn new() -> MultiIssueEntityProperties
A list of issues and their respective properties to set or update. See Entity properties for more information.