pub struct Project {Show 34 fields
pub expand: Option<String>,
pub _self: Option<String>,
pub id: Option<String>,
pub key: Option<String>,
pub description: Option<String>,
pub lead: Option<User>,
pub components: Option<Vec<ProjectComponent>>,
pub issue_types: Option<Vec<IssueTypeDetails>>,
pub url: Option<String>,
pub email: Option<String>,
pub assignee_type: Option<AssigneeType>,
pub versions: Option<Vec<Version>>,
pub name: Option<String>,
pub roles: Option<HashMap<String, String>>,
pub avatar_urls: Option<AvatarUrlsBean>,
pub project_category: Option<ProjectCategory>,
pub project_type_key: Option<ProjectTypeKey>,
pub simplified: Option<bool>,
pub style: Option<Style>,
pub favourite: Option<bool>,
pub is_private: Option<bool>,
pub issue_type_hierarchy: Option<Hierarchy>,
pub permissions: Option<ProjectPermissions>,
pub properties: Option<HashMap<String, Value>>,
pub uuid: Option<String>,
pub insight: Option<ProjectInsight>,
pub deleted: Option<bool>,
pub retention_till_date: Option<String>,
pub deleted_date: Option<String>,
pub deleted_by: Option<User>,
pub archived: Option<bool>,
pub archived_date: Option<String>,
pub archived_by: Option<User>,
pub landing_page_info: Option<ProjectLandingPageInfo>,
}Expand description
Project : Details about a project.
Fields
expand: Option<String>Expand options that include additional project details in the response.
_self: Option<String>The URL of the project details.
id: Option<String>The ID of the project.
key: Option<String>The key of the project.
description: Option<String>A brief description of the project.
lead: Option<User>The username of the project lead.
components: Option<Vec<ProjectComponent>>List of the components contained in the project.
issue_types: Option<Vec<IssueTypeDetails>>List of the issue types available in the project.
url: Option<String>A link to information about this project, such as project documentation.
email: Option<String>An email address associated with the project.
assignee_type: Option<AssigneeType>The default assignee when creating issues for this project.
versions: Option<Vec<Version>>The versions defined in the project. For more information, see Create version.
name: Option<String>The name of the project.
roles: Option<HashMap<String, String>>The name and self URL for each role defined in the project. For more information, see Create project role.
avatar_urls: Option<AvatarUrlsBean>The URLs of the project’s avatars.
project_category: Option<ProjectCategory>The category the project belongs to.
project_type_key: Option<ProjectTypeKey>The project type of the project.
simplified: Option<bool>Whether the project is simplified.
style: Option<Style>The type of the project.
favourite: Option<bool>Whether the project is selected as a favorite.
is_private: Option<bool>Whether the project is private.
issue_type_hierarchy: Option<Hierarchy>The issue type hierarchy for the project.
permissions: Option<ProjectPermissions>User permissions on the project
properties: Option<HashMap<String, Value>>Map of project properties
uuid: Option<String>Unique ID for next-gen projects.
insight: Option<ProjectInsight>Insights about the project.
deleted: Option<bool>Whether the project is marked as deleted.
retention_till_date: Option<String>The date when the project is deleted permanently.
deleted_date: Option<String>The date when the project was marked as deleted.
deleted_by: Option<User>The user who marked the project as deleted.
archived: Option<bool>Whether the project is archived.
archived_date: Option<String>The date when the project was archived.
archived_by: Option<User>The user who archived the project.
landing_page_info: Option<ProjectLandingPageInfo>The project landing page info.