pub struct UpdateScreenTypes {
pub edit: Option<String>,
pub create: Option<String>,
pub view: Option<String>,
pub default: Option<String>,
}Expand description
UpdateScreenTypes : The IDs of the screens for the screen types of the screen scheme.
Fields
edit: Option<String>The ID of the edit screen. To remove the screen association, pass a null.
create: Option<String>The ID of the create screen. To remove the screen association, pass a null.
view: Option<String>The ID of the view screen. To remove the screen association, pass a null.
default: Option<String>The ID of the default screen. When specified, must include a screen ID as a default screen is required.
Implementations
Sourceimpl UpdateScreenTypes
impl UpdateScreenTypes
Sourcepub fn new() -> UpdateScreenTypes
pub fn new() -> UpdateScreenTypes
The IDs of the screens for the screen types of the screen scheme.