pub struct AddWorklogParams {
pub issue_id_or_key: String,
pub request_body: HashMap<String, Value>,
pub notify_users: Option<bool>,
pub adjust_estimate: Option<String>,
pub new_estimate: Option<String>,
pub reduce_by: Option<String>,
pub expand: Option<String>,
pub override_editable_flag: Option<bool>,
}Expand description
struct for passing parameters to the method add_worklog
Fields
issue_id_or_key: StringThe ID or key the issue.
request_body: HashMap<String, Value>notify_users: Option<bool>Whether users watching the issue are notified by email.
adjust_estimate: Option<String>Defines how to update the issue’s time estimate, the options are: * new Sets the estimate to a specific value, defined in newEstimate. * leave Leaves the estimate unchanged. * manual Reduces the estimate by amount specified in reduceBy. * auto Reduces the estimate by the value of timeSpent in the worklog.
new_estimate: Option<String>The value to set as the issue’s remaining time estimate, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, 2d. Required when adjustEstimate is new.
reduce_by: Option<String>The amount to reduce the issue’s remaining estimate by, as days (\#d), hours (\#h), or minutes (\#m). For example, 2d. Required when adjustEstimate is manual.
expand: Option<String>Use expand to include additional information about work logs in the response. This parameter accepts properties, which returns worklog properties.
override_editable_flag: Option<bool>Whether the worklog entry should be added to the issue even if the issue is not editable, because jira.issue.editable set to false or missing. For example, the issue is closed. Connect app users with admin permission and Forge app users with the manage:jira-configuration scope can use this flag.